unofficial mirror of bug-gnu-emacs@gnu.org 
 help / color / mirror / code / Atom feed
* bug#12771: 24.2.50; Gomoku displays statistics in other buffers
@ 2012-10-31 11:23 Stephen Berman
  2012-11-01  2:25 ` Chong Yidong
  0 siblings, 1 reply; 2+ messages in thread
From: Stephen Berman @ 2012-10-31 11:23 UTC (permalink / raw)
  To: 12771

0. emacs -Q
1. M-x gomoku
2. Answer the question to start playing, or type C-g.
3. C-x k to kill the *Gomoku* buffer.
   => Now the current buffer is *scratch*; note the mode line text:
   " U:**-  *scratch*      All L5     (Lisp Interaction) "
4. M-x gomoku
   => The mode line of *scratch* now looks like this:
   " U:**-  *scratch*      All L5     (Lisp Interaction: Won 0, lost 0) "

As a result of killing the *Gomoku* buffer in step 3, the gomoku command
in step 4 tests gomoku-game-in-progress, and because its value is still
t (since the game was not finished), gomoku-terminate-game is called,
which in turn calls gomoku-display-statistics, which changes the mode
line of the current buffer, which is still *scratch* here.  The patch
below prevents this by ensuring the mode line is only changed if the
*Gomoku* buffer is current.

In addition, the patch changes "Won" to "won", which I believe conforms
to standard practice in English for use of capitalization after a colon
(cf. http://en.wikipedia.org/wiki/Colon_%28punctuation%29) and looks
better to me.  (However, the patch doesn't change the use of
mode-line-process for displaying the statistics, despite the comment
acknowledging that this is not clean.)


In GNU Emacs 24.2.50.1 (x86_64-suse-linux-gnu, GTK+ Version 3.4.4)
 of 2012-10-27 on rosalinde
Bzr revision: 110689 eliz@gnu.org-20121027112126-wznlfl8la6gwukh6
Windowing system distributor `The X.Org Foundation', version 11.0.11203000
System Description:	openSUSE 12.2 (x86_64)


2012-10-31  Stephen Berman  <stephen.berman@gmx.net>

	* play/gomoku.el (gomoku-display-statistics): Update mode line
	only when Gomoku buffer is current.  Don't capitalize "won", to
	conform to standard practice. (Bug#xxxxxx)

=== modified file 'lisp/play/gomoku.el'
--- lisp/play/gomoku.el	2012-09-01 01:04:26 +0000
+++ lisp/play/gomoku.el	2012-10-31 10:25:10 +0000
@@ -1054,16 +1054,18 @@
 
 (defun gomoku-display-statistics ()
   "Obnoxiously display some statistics about previous games in mode line."
-  ;; We store this string in the mode-line-process local variable.
-  ;; This is certainly not the cleanest way out ...
-  (setq mode-line-process
-	(format ": Won %d, lost %d%s"
-		gomoku-number-of-human-wins
-		gomoku-number-of-emacs-wins
-		(if (zerop gomoku-number-of-draws)
-		    ""
-		  (format ", drew %d" gomoku-number-of-draws))))
-  (force-mode-line-update))
+  ;; Update mode line only when Gomoku buffer is current (bug#xxxxxx).
+  (when (string= (buffer-name) gomoku-buffer-name)
+    ;; We store this string in the mode-line-process local variable.
+    ;; This is certainly not the cleanest way out ...
+    (setq mode-line-process
+	  (format ": won %d, lost %d%s"
+		  gomoku-number-of-human-wins
+		  gomoku-number-of-emacs-wins
+		  (if (zerop gomoku-number-of-draws)
+		      ""
+		    (format ", drew %d" gomoku-number-of-draws))))
+    (force-mode-line-update)))
 
 (defun gomoku-switch-to-window ()
   "Find or create the Gomoku buffer, and display it."






^ permalink raw reply	[flat|nested] 2+ messages in thread

* bug#12771: 24.2.50; Gomoku displays statistics in other buffers
  2012-10-31 11:23 bug#12771: 24.2.50; Gomoku displays statistics in other buffers Stephen Berman
@ 2012-11-01  2:25 ` Chong Yidong
  0 siblings, 0 replies; 2+ messages in thread
From: Chong Yidong @ 2012-11-01  2:25 UTC (permalink / raw)
  To: Stephen Berman; +Cc: 12771-done

Stephen Berman <stephen.berman@gmx.net> writes:

> As a result of killing the *Gomoku* buffer in step 3, the gomoku command
> in step 4 tests gomoku-game-in-progress, and because its value is still
> t (since the game was not finished), gomoku-terminate-game is called,
> which in turn calls gomoku-display-statistics, which changes the mode
> line of the current buffer, which is still *scratch* here.  The patch
> below prevents this by ensuring the mode line is only changed if the
> *Gomoku* buffer is current.

Committed, thanks.





^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2012-11-01  2:25 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2012-10-31 11:23 bug#12771: 24.2.50; Gomoku displays statistics in other buffers Stephen Berman
2012-11-01  2:25 ` Chong Yidong

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).